@@ -174,6 +174,12 @@ extern "C" {
 /* force column encryption */
 #define SQL_CA_SS_FORCE_ENCRYPT                     (SQL_CA_SS_BASE+36) /*  indicate mandatory encryption for this parameter */
 
+/* Data Classification */
+#define SQL_CA_SS_DATA_CLASSIFICATION               (SQL_CA_SS_BASE+37) /*  retrieve data classification information */
+
+/* Data Classification version*/
+#define SQL_CA_SS_DATA_CLASSIFICATION_VERSION       (SQL_CA_SS_BASE+38) /*  retrieve data classification version */
+
 /* Defines for use with SQL_COPT_SS_PRESERVE_CURSORS */
 #define SQL_PC_OFF                          0L           /*  Cursors are closed on SQLTransact */
 #define SQL_PC_ON                           1L           /*  Cursors remain open on SQLTransact */
